@@ -37,6 +37,7 @@
 #include "gnome-vfs-async-job-map.h"
 #include "gnome-vfs-thread-pool.h"
 #include "gnome-vfs-job-queue.h"
+#include "gnome-vfs-volume-monitor-private.h"
 
 #include <errno.h>
 #include <bonobo-activation/bonobo-activation.h>
@@ -58,16 +59,16 @@ ensure_dot_gnome_exists (void)
 	gboolean retval = TRUE;
 	gchar *dirname;
 
-	dirname = g_build_filename (g_get_home_dir (), ".gnome", NULL);
+	dirname = g_build_filename (g_get_home_dir (), ".gnome2", NULL);
 
 	if (!g_file_test (dirname, G_FILE_TEST_EXISTS)) {
 		if (mkdir (dirname, S_IRWXU) != 0) {
-			g_warning ("Unable to create ~/.gnome directory: %s",
+			g_warning ("Unable to create ~/.gnome2 directory: %s",
 				   g_strerror (errno));
 			retval = FALSE;
 		}
 	} else if (!g_file_test (dirname, G_FILE_TEST_IS_DIR)) {
-		g_warning ("Error: ~/.gnome must be a directory.");
+		g_warning ("Error: ~/.gnome2 must be a directory.");
 		retval = FALSE;
 	}
 
@@ -123,7 +124,7 @@ gnome_vfs_init (void)
 		if (bonobo_activation_orb_get() == NULL) {
 			bonobo_activation_init (0, bogus_argv);
 		}
-		bonobo_init (0, bogus_argv);
+		bonobo_init (NULL, bogus_argv);
 
 
 		_gnome_vfs_ssl_init ();
@@ -180,6 +181,7 @@ gnome_vfs_shutdown (void)
 {
 	_gnome_vfs_thread_backend_shutdown ();
 	gnome_vfs_mime_shutdown ();
+	_gnome_vfs_volume_monitor_shutdown ();
 	_gnome_vfs_client_shutdown ();
 	bonobo_debug_shutdown ();
 }
