@@ -161,7 +161,6 @@ static gboolean sftp_connection_process_errors (GIOChannel *channel,
 						GIOCondition cond,
 						GnomeVFSResult *status);
 
-
 
 static guint inited_buffers = 0;
 
@@ -647,8 +646,6 @@ buffer_write_file_info (Buffer *buf, const GnomeVFSFileInfo *info, GnomeVFSSetFi
 	}
 }
 
-
-
 static GnomeVFSResult 
 sftp_status_to_vfs_result (guint status) 
 {
@@ -676,7 +673,6 @@ sftp_status_to_vfs_result (guint status)
 	}
 }
 
-
 
 /* Derived from OpenSSH, sftp-client.c:get_status */
 
@@ -844,8 +840,6 @@ iobuf_send_string_request_with_file_info (int                      fd,
 	buffer_free (&msg);
 }
 
-
-
 static char*
 get_user_from_uri_or_password_line (const GnomeVFSURI *uri,
 				    const char *password_line)
@@ -904,8 +898,6 @@ get_authtype_from_password_line (const char *password_line)
 	return g_strdup ("password");
 }
 
-
-
 static gboolean
 invoke_fill_auth (const GnomeVFSURI *uri,
 		  const char *password_line,
@@ -1253,14 +1245,14 @@ sftp_connect (SftpConnection **connection, const GnomeVFSURI *uri)
 		FD_SET (in_fd, &ifds);
 		FD_SET (prompt_fd, &ifds);
 
-		tv.tv_sec = 10;
+		tv.tv_sec = 20;
 		tv.tv_usec = 0;
 
 		ret = select (MAX (in_fd, prompt_fd)+1, &ifds, NULL, NULL, &tv);
 
 		if (ret <= 0) {
 			/* Timeout */
-			res = GNOME_VFS_ERROR_IO;
+			res = GNOME_VFS_ERROR_TIMEOUT;
 			goto bail;
 		}
 
@@ -1702,8 +1694,6 @@ sftp_connection_unref (SftpConnection *conn)
 	}
 }
 
-
-
 /* Portions of the below functions inspired by functions in OpenSSH sftp-client.c */
 
 static GnomeVFSResult
@@ -1769,8 +1759,6 @@ get_real_path (SftpConnection *conn, const gchar *path, gchar **realpath)
 	return GNOME_VFS_OK;
 }
 
-
-
 static GnomeVFSResult 
 do_open (GnomeVFSMethod        *method,
 	 GnomeVFSMethodHandle **method_handle,
@@ -1796,6 +1784,8 @@ do_open (GnomeVFSMethod        *method,
 	if (res != GNOME_VFS_OK) return res;
 
 	path = gnome_vfs_unescape_string (gnome_vfs_uri_get_path (uri), NULL);
+	if (path == NULL)
+		return GNOME_VFS_ERROR_INVALID_URI;
 
 	id = sftp_connection_get_id (conn);
 
@@ -1809,7 +1799,8 @@ do_open (GnomeVFSMethod        *method,
 	sftp_mode = 0;
 	if (mode & GNOME_VFS_OPEN_READ) sftp_mode |= SSH2_FXF_READ;
 	if (mode & GNOME_VFS_OPEN_WRITE) sftp_mode |= SSH2_FXF_WRITE;
-	if ((mode & GNOME_VFS_OPEN_WRITE) && !(mode & GNOME_VFS_OPEN_RANDOM))
+	if ((mode & GNOME_VFS_OPEN_TRUNCATE) ||
+	    ((mode & GNOME_VFS_OPEN_WRITE) && !(mode & GNOME_VFS_OPEN_RANDOM)))
 		sftp_mode |= SSH2_FXF_TRUNC;
 
 	buffer_write_gint32 (&msg, sftp_mode);
@@ -1872,6 +1863,8 @@ do_create (GnomeVFSMethod        *method,
 	if (res != GNOME_VFS_OK) return res;
 
 	path = gnome_vfs_unescape_string (gnome_vfs_uri_get_path (uri), NULL);
+	if (path == NULL)
+		return GNOME_VFS_ERROR_INVALID_URI;
 
 	id = sftp_connection_get_id (conn);
 
@@ -2343,6 +2336,8 @@ do_get_file_info (GnomeVFSMethod          *method,
 	if (res != GNOME_VFS_OK) return res;
 
 	path = gnome_vfs_unescape_string (gnome_vfs_uri_get_path (uri), NULL);
+	if (path == NULL)
+		return GNOME_VFS_ERROR_INVALID_URI;
 
 	if (options & GNOME_VFS_FILE_INFO_FOLLOW_LINKS) {
 		res = get_real_path (conn, path, &real_path);
@@ -2451,6 +2446,8 @@ do_open_directory (GnomeVFSMethod          *method,
 	id = sftp_connection_get_id (conn);
 
 	path = gnome_vfs_unescape_string (gnome_vfs_uri_get_path (uri), NULL);
+	if (path == NULL)
+		return GNOME_VFS_ERROR_INVALID_URI;
 
 	/* If the path is empty (i.e. root directory), then give it the root directory explicitly */
 	if (!strcmp (path, "")) {
@@ -2690,6 +2687,9 @@ do_make_directory (GnomeVFSMethod  *method,
 	id = sftp_connection_get_id (conn);
 
 	path = gnome_vfs_unescape_string (gnome_vfs_uri_get_path (uri), NULL);
+	if (path == NULL)
+		return GNOME_VFS_ERROR_INVALID_URI;
+
 	memset (&info, 0, sizeof (GnomeVFSFileInfo));
 	iobuf_send_string_request_with_file_info (conn->out_fd, id, SSH2_FXP_MKDIR,
 						  path, strlen (path), &info,
@@ -2705,7 +2705,6 @@ do_make_directory (GnomeVFSMethod  *method,
 	return res;
 }
 
-
 static GnomeVFSResult
 do_remove_directory (GnomeVFSMethod  *method,
 		     GnomeVFSURI     *uri,
@@ -2722,6 +2721,9 @@ do_remove_directory (GnomeVFSMethod  *method,
 	id = sftp_connection_get_id (conn);
 
 	path = gnome_vfs_unescape_string (gnome_vfs_uri_get_path (uri), NULL);
+	if (path == NULL)
+		return GNOME_VFS_ERROR_INVALID_URI;
+
 	iobuf_send_string_request (conn->out_fd, id, SSH2_FXP_RMDIR, path, strlen (path));
 
 	g_free (path);
@@ -2755,10 +2757,27 @@ do_move (GnomeVFSMethod  *method,
 	buffer_init (&msg);
 
 	old_path = gnome_vfs_unescape_string (gnome_vfs_uri_get_path (old_uri), NULL);
+	if (old_path == NULL)
+		return GNOME_VFS_ERROR_INVALID_URI;
+
 	new_path = gnome_vfs_unescape_string (gnome_vfs_uri_get_path (new_uri), NULL);
+	if (new_path == NULL)
+		return GNOME_VFS_ERROR_INVALID_URI;
 
 	id = sftp_connection_get_id (conn);
 
+	/* if force_replace is specified, try to remove new_uri */
+	if (force_replace) {
+		iobuf_send_string_request (conn->out_fd,
+					   id,
+					   SSH2_FXP_REMOVE,
+					   new_path,
+					   strlen (new_path));
+		res = iobuf_read_result (conn->in_fd, id);
+		if (res != GNOME_VFS_OK && res != GNOME_VFS_ERROR_NOT_FOUND)
+			goto bail;
+	}
+
 	buffer_write_gchar (&msg, SSH2_FXP_RENAME);
 	buffer_write_gint32 (&msg, id);
 	buffer_write_string (&msg, old_path);
@@ -2766,11 +2785,12 @@ do_move (GnomeVFSMethod  *method,
 	buffer_send (&msg, conn->out_fd);
 	buffer_free (&msg);
 
+	res = iobuf_read_result (conn->in_fd, id);
+
+ bail:
 	g_free (old_path);
 	g_free (new_path);
 
-	res = iobuf_read_result (conn->in_fd, id);
-
 	sftp_connection_unref (conn);
 	sftp_connection_unlock (conn);
 
@@ -2798,8 +2818,15 @@ do_rename (GnomeVFSMethod  *method,
 	buffer_init (&msg);
 
 	old_path = gnome_vfs_unescape_string (gnome_vfs_uri_get_path (old_uri), NULL);
+	if (old_path == NULL)
+		return GNOME_VFS_ERROR_INVALID_URI;
+
 	old_dirname = g_path_get_dirname (old_path);
+
 	new_path = g_build_filename (old_dirname, new_name, NULL);
+	if (new_path == NULL)
+		return GNOME_VFS_ERROR_INVALID_URI;
+
 	g_free (old_dirname);
 
 	id = sftp_connection_get_id (conn);
@@ -2838,6 +2865,9 @@ do_unlink (GnomeVFSMethod  *method,
 	id = sftp_connection_get_id (conn);
 
 	path = gnome_vfs_unescape_string (gnome_vfs_uri_get_path (uri), NULL);
+	if (path == NULL)
+		return GNOME_VFS_ERROR_INVALID_URI;
+
 	iobuf_send_string_request (conn->out_fd, id, SSH2_FXP_REMOVE, path, strlen (path));
 
 	g_free (path);
@@ -2907,6 +2937,9 @@ do_set_file_info (GnomeVFSMethod          *method,
 		id = sftp_connection_get_id (conn);
 
 		path = gnome_vfs_unescape_string (gnome_vfs_uri_get_path (uri), NULL);
+		if (path == NULL)
+			return GNOME_VFS_ERROR_INVALID_URI;
+
 		iobuf_send_string_request_with_file_info (conn->out_fd, id, SSH2_FXP_SETSTAT,
 							  path, strlen (path), info, mask);
 
@@ -2950,6 +2983,8 @@ do_create_symlink (GnomeVFSMethod   *method,
 	buffer_init (&msg);
 
 	path = gnome_vfs_unescape_string (gnome_vfs_uri_get_path (uri), NULL);
+	if (path == NULL)
+		return GNOME_VFS_ERROR_INVALID_URI;
 
 	id = sftp_connection_get_id (conn);
 
@@ -2970,7 +3005,6 @@ do_create_symlink (GnomeVFSMethod   *method,
 	return res;
 }
 
-
 
 static GnomeVFSMethod method = {
 	sizeof (GnomeVFSMethod),
